// Define the dimensions of the visualization.
const width = 800;
const height = 400;
const margin = {top:20, right:20, bottom:20, left:20};

// Create the SVG canvas.
const svg = d3.select("#arbre_svg")
  .attr("width", width)
  .attr("height", height);

const g = svg.append("g")
  .attr("transform", `translate(${margin.left},${margin.top})`);

// la forêt d'arbres
let data = [
  {
    id: 1,
    name: "Arbre 1",
    children: [
      {
        name: "x1",
        children: [
          { name: "x2" },
          {
            name: "x3",
            children: [
              { name: "x4" },
              { name: "x5" },
            ],
          },
        ],
      },
    ],
  },
  {
    id: 2,
    name: "Arbre 2",
    children: [
      {
        name: "x6",
        children: [
          {
            name: "x3",
            children: [
              { name: "x1" },
              { name: "x8" },
            ],
          },
          {
            name: "x7",
            children: [
              { name: "x2" },
              { name: "x4" },
            ],
          },
        ],
      },
    ],
  },
  {
    id: 3,
    name: "Arbre 3",
    children: [
      {
        name: "x8",
        children: [
          {
            name: "x4",
            children: [
              { name: "x1" },
              { name: "x3" },
            ],
          },
          {
            name: "x5",
            children: [
              { name: "x4" },
              { name: "x2" },
            ],
          },
        ],
      },
    ],
  },
  {
    id: 4,
    name: "Arbre 4",
    children: [
      {
        name: "x2",
        children: [
          {
            name: "x1",
            children: [
              { name: "x4" },
              { name: "x3" },
            ],
          },
          { name: "x8" },
        ],
      },
    ],
  },
];

// arbre de disposition
const treeLayout = d3.tree().size(
  [0.6 * (height - margin.top - margin.bottom), 
  0.6 * (width - margin.left - margin.right)]
);

// fonction pour générer les arbres hiérarchiques à partir des données
function generateTree(treeData) {
  const root = d3.hierarchy(treeData);
  return treeLayout(root);
}

data = data.map(generateTree);

let xOffset = 0;
let maxHeight = 0;

data.forEach((tree, index) => {
  const treeWidths = tree.descendants().map(d => d.x);
  const maxTreeWidth = Math.max(...treeWidths);
  const treeHeights = tree.descendants().map(d => d.y);
  const maxTreeHeight = Math.max(...treeHeights);

  const treeGroup = g.append("g")
    .attr("transform", `translate(${xOffset}, 0)`);

 // Dessiner les noeuds
const nodes = treeGroup.selectAll(".node")
  .data(tree.descendants())
  .enter().append("g")
    .attr("class", "node")
    .attr("transform", (d) => `translate(${d.x},${d.y})`)
    .on("mouseover", function(d) {
      tooltip.transition()
        .duration(200)
        .style("opacity", .9);
      tooltip.html(d.data.name)
        .style("left", (d3.event.pageX) + "px")
        .style("top", (d3.event.pageY - 28) + "px");
    })
    .on("mouseout", function(d) {
      tooltip.transition()
        .duration(500)
        .style("opacity", 0);
    });

nodes.append("circle")
  .attr("r", 12)
  .attr("fill", "black");

// Ajouter une info-bulle pour afficher le nom du nœud
const tooltip = d3.select("body").append("div")
  .attr("class", "tooltip")
  .style("opacity", 0);

  // Dessinez les liens
  const links = treeGroup.selectAll(".link")
    .data(tree.links())
    .enter().append("path")
      .attr("class", "link")
      .attr("d", d3.linkVertical().x(d => d.x).y(d => d.y))
      .attr("stroke", "black")
      .attr("fill", "none");

  xOffset += maxTreeWidth + margin.right;
  maxHeight = Math.max(maxHeight, maxTreeHeight);
});

// Ajustez la largeur et la hauteur de la zone de dessin si nécessaire
const totalWidth = xOffset + margin.right;
const totalHeight = maxHeight + margin.top + margin.bottom;
if (totalWidth > width) {
  svg.attr("width", totalWidth);
}
if (totalHeight > height) {
  svg.attr("height", totalHe